==> igniteui-react-layouts-18.0.0.tgz: package/esm5/lib/igr-tool-action-event-detail.js <==
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionType_$type } from "igniteui-react-core";
import { ToolActionEventDetail as ToolActionEventDetail_internal } from "./ToolActionEventDetail";
import { ensureEnum, ensureBool } from "igniteui-react-core";
var IgrToolActionEventDetail = /** @class */ /*@__PURE__*/ (function () {
    function IgrToolActionEventDetail() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrToolActionEventDetail.prototype.createImplementation = function () {
        return new ToolActionEventDetail_internal();
    };
    Object.defineProperty(IgrToolActionEventDetail.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrToolActionEventDetail.prototype.onImplementationCreated = function () {
    };
    IgrToolActionEventDetail.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrToolActionEventDetail.prototype, "action", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            if (!this.i.a.externalObject) {
                var e = IgrToolAction._createFromInternal(this.i.a);
                if (e) {
                    e._implementation = this.i.a;
                }
                this.i.a.externalObject = e;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionEventDetail.prototype, "actionType", {
        get: function () {
            return this.i.b;
        },
        set: function (v) {
            this.i.b = ensureEnum(ToolActionType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionEventDetail.prototype, "isModified", {
        get: function () {
            return this.i.d;
        },
        set: function (v) {
            this.i.d = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionEventDetail.prototype, "boolValue", {
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionEventDetail.prototype, "numberValue", {
        get: function () {
            return this.i.f;
        },
        set: function (v) {
            this.i.f = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionEventDetail.prototype, "dateTimeValue", {
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionEventDetail.prototype, "untypedValue", {
        get: function () {
            return this.i.g;
        },
        set: function (v) {
            this.i.g = v;
        },
        enumerable: false,
        configurable: true
    });
    IgrToolActionEventDetail.prototype.findByName = function (name) {
        if (this.action && this.action.name && this.action.name == name) {
            return this.action;
        }
        return null;
    };
    return IgrToolActionEventDetail;
}());
export { IgrToolActionEventDetail };

==> igniteui-react-layouts-18.2.0.tgz: package/esm5/lib/igr-tool-action-event-detail.js <==
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionType_$type } from "igniteui-react-core";
import { ToolActionEventDetail as ToolActionEventDetail_internal } from "./ToolActionEventDetail";
import { ensureEnum, ensureBool } from "igniteui-react-core";
var IgrToolActionEventDetail = /** @class */ /*@__PURE__*/ (function () {
    function IgrToolActionEventDetail() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrToolActionEventDetail.prototype.createImplementation = function () {
        return new ToolActionEventDetail_internal();
    };
    Object.defineProperty(IgrToolActionEventDetail.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrToolActionEventDetail.prototype.onImplementationCreated = function () {
    };
    IgrToolActionEventDetail.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrToolActionEventDetail.prototype, "action", {
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrToolAction._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionEventDetail.prototype, "actionType", {
        get: function () {
            return this.i.b;
        },
        set: function (v) {
            this.i.b = ensureEnum(ToolActionType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionEventDetail.prototype, "isModified", {
        get: function () {
            return this.i.d;
        },
        set: function (v) {
            this.i.d = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionEventDetail.prototype, "boolValue", {
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionEventDetail.prototype, "numberValue", {
        get: function () {
            return this.i.f;
        },
        set: function (v) {
            this.i.f = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionEventDetail.prototype, "dateTimeValue", {
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionEventDetail.prototype, "untypedValue", {
        get: function () {
            return this.i.g;
        },
        set: function (v) {
            this.i.g = v;
        },
        enumerable: false,
        configurable: true
    });
    IgrToolActionEventDetail.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        if (this.action && this.action.name && this.action.name == name) {
            return this.action;
        }
        return null;
    };
    return IgrToolActionEventDetail;
}());
export { IgrToolActionEventDetail };
